Dallinger Demos
===============

The demos can be run locally on your machine in "debug" mode.
Running the demos in "sandbox" mode will require a Heroku account.

More information for :doc:`running in "sandbox" mode <demos_on_heroku>`.

.. toctree::
    :maxdepth: 1
    :caption: Demos
    :glob:

    demos/bartlett1932/*
    demos/chatroom/*
    demos/concentration/*
    demos/function_learning/*
    demos/iterated_drawing/*
    demos/mcmcp/*
    demos/rogers/*
    demos/sheep_market/*
    demos/snake/*
    demos/twentyfortyeight/*
    demos/vox_populi/*
